==> sds-button-toggle-0.1.13.tgz: package/button-toggle.js <==
/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import {
  defaultState,
  firstRender,
  render,
  setState,
  state,
  stateEffects,
  template,
} from 'elix/src/base/internal';
import { fragmentFrom } from 'elix/src/core/htmlLiterals';

import SdsButton from '@salesforce-ux/sds-button/button';
import css from './button-toggle.module.css';

const KEYCODE = {
  SPACE: 32,
  ENTER: 13,
};

export default class SdsButtonToggle extends SdsButton {
  get [defaultState]() {
    return Object.assign(super[defaultState], {
      pressed: null,
    });
  }

  /**
   * When a user activates the button and toggles between pressed and unpressed.
   */
  get pressed() {
    return this[state].pressed;
  }

  set pressed(pressed) {
    this[setState]({
      pressed: pressed,
    });
  }

  /**
   * Track keydown for accessibility
   * @param {event} e
   */
  _onKeyDown(e) {
    if (e.altKey) return;
    switch (e.keyCode) {
      case KEYCODE.SPACE:
      case KEYCODE.ENTER:
        e.preventDefault();
        this._togglePressed();
        break;
      default:
        break;
    }
  }

  /**
   * Add attributes based if the user toggles the button
   */
  _togglePressed() {
    this.toggleAttribute('pressed');
  }

  /**
   * Listen for changes to our 'pressed' state and handle side effects
   * to the button element's aria attribute. Listening for attribute changes
   * allows the aria attribute to respond to dynamic attribute changes and
   * not only keyboard/click events.
   */
  [stateEffects](state, changed) {
    const effects = super[stateEffects] ? super[stateEffects](state, changed) : {};
    if (changed.pressed) {
      const { pressed } = state;
      const isPressed = pressed !== null;
      Object.assign(effects, {
        ariaPressed: isPressed,
      });
    }
    return effects;
  }

  [render](changed) {
    super[render](changed);
    const button = this.shadowRoot.querySelector('[part="button"]');

    /**
     * Setup event listeners on first load
     */
    if (this[firstRender]) {
      this.addEventListener('keydown', this._onKeyDown);
      this.addEventListener('click', this._togglePressed);
    }

    delegateAttribute(this, button, 'aria-pressed', this[state].ariaPressed);
  }

  get [template]() {
    const result = super[template];

    result.content.append(fragmentFrom.html`
    <style>
      ${css}
    </style>
    `);

    return result;
  }
}

function delegateAttribute(from, to, name, value) {
  if (value || typeof value === 'boolean') {
    to.setAttribute(name, value);
    from.removeAttribute(name);
  } else {
    to.removeAttribute(name);
  }
}

==> sds-button-toggle-0.1.14.tgz: package/button-toggle.js <==
/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import {
  defaultState,
  firstRender,
  render,
  setState,
  state,
  stateEffects,
  template,
} from 'elix/src/base/internal';
import { fragmentFrom } from 'elix/src/core/htmlLiterals';
import { delegateAttribute } from '@salesforce-ux/sds-utils';

import SdsButton from '@salesforce-ux/sds-button/button';
import css from './button-toggle.module.css';

const KEYCODE = {
  SPACE: 32,
  ENTER: 13,
};

export default class SdsButtonToggle extends SdsButton {
  get [defaultState]() {
    return Object.assign(super[defaultState], {
      pressed: null,
    });
  }

  /**
   * When a user activates the button and toggles between pressed and unpressed.
   */
  get pressed() {
    return this[state].pressed;
  }

  set pressed(pressed) {
    this[setState]({
      pressed: pressed,
    });
  }

  /**
   * Track keydown for accessibility
   * @param {event} e
   */
  _onKeyDown(e) {
    if (e.altKey) return;
    switch (e.keyCode) {
      case KEYCODE.SPACE:
      case KEYCODE.ENTER:
        e.preventDefault();
        this._togglePressed();
        break;
      default:
        break;
    }
  }

  /**
   * Add attributes based if the user toggles the button
   */
  _togglePressed() {
    this.toggleAttribute('pressed');
  }

  /**
   * Listen for changes to our 'pressed' state and handle side effects
   * to the button element's aria attribute. Listening for attribute changes
   * allows the aria attribute to respond to dynamic attribute changes and
   * not only keyboard/click events.
   */
  [stateEffects](state, changed) {
    const effects = super[stateEffects] ? super[stateEffects](state, changed) : {};
    if (changed.pressed) {
      const { pressed } = state;
      const isPressed = pressed !== null;
      Object.assign(effects, {
        ariaPressed: isPressed ? 'true' : 'false',
      });
    }
    return effects;
  }

  [render](changed) {
    super[render](changed);
    const button = this.shadowRoot.querySelector('[part="button"]');

    /**
     * Setup event listeners on first load
     */
    if (this[firstRender]) {
      this.addEventListener('keydown', this._onKeyDown);
      this.addEventListener('click', this._togglePressed);
    }
    if (changed.ariaPressed) {
      delegateAttribute(this, button, 'aria-pressed', this[state].ariaPressed);
    }
  }

  get [template]() {
    const result = super[template];

    result.content.append(fragmentFrom.html`
    <style>
      ${css}
    </style>
    `);

    return result;
  }
}
